@@ -1,5 +1,5 @@
 /* This file is part of GDBM, the GNU data base manager.
-   Copyright (C) 2011, 2013, 2017-2018 Free Software Foundation, Inc.
+   Copyright (C) 2011, 2013, 2017-2020 Free Software Foundation, Inc.
 
    GDBM is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -19,8 +19,8 @@
 # include "gdbmapp.h"
 # include "gdbmdefs.h"
 
-char *parseopt_program_doc = "dump a GDBM database to a file";
-char *parseopt_program_args = "DB_FILE [FILE]";
+char *parseopt_program_doc = N_("dump a GDBM database to a file");
+char *parseopt_program_args = N_("DB_FILE [FILE]");
 struct gdbm_option optab[] = {
   { 'H', "format", "binary|ascii|0|1", N_("select dump format") },
   { 0 }
