@@ -1,7 +1,7 @@
 /* gdbmsync.c - Sync the disk with the in memory state. */
 
 /* This file is part of GDBM, the GNU data base manager.
-   Copyright (C) 1990-1991, 1993, 2007, 2011, 2013, 2016-2018 Free
+   Copyright (C) 1990-1991, 1993, 2007, 2011, 2013, 2016-2020 Free
    Software Foundation, Inc.
 
    GDBM is free software; you can redistribute it and/or modify
@@ -28,7 +28,7 @@ int
 gdbm_sync (GDBM_FILE dbf)
 {
   /* Return immediately if the database needs recovery */	
-  GDBM_ASSERT_CONSISTENCY (dbf, );
+  GDBM_ASSERT_CONSISTENCY (dbf, -1);
 
   /* Initialize the gdbm_errno variable. */
   gdbm_set_errno (dbf, GDBM_NO_ERROR, FALSE);
