@@ -1,7 +1,7 @@
 /* update.c - The routines for updating the file to a consistent state. */
 
 /* This file is part of GDBM, the GNU data base manager.
-   Copyright (C) 1990-1991, 1993, 2007, 2011, 2013, 2016-2018 Free
+   Copyright (C) 1990-1991, 1993, 2007, 2011, 2013, 2016-2020 Free
    Software Foundation, Inc.
 
    GDBM is free software; you can redistribute it and/or modify
@@ -30,8 +30,7 @@ write_header (GDBM_FILE dbf)
   off_t file_pos;	/* Return value for lseek. */
   int rc;
 
-  file_pos = GDBM_DEBUG_OVERRIDE ("write_header:lseek-failure",
-				  __lseek (dbf, 0L, SEEK_SET));
+  file_pos = gdbm_file_seek (dbf, 0L, SEEK_SET);
   if (file_pos != 0)
     {
       GDBM_SET_ERRNO2 (dbf, GDBM_FILE_SEEK_ERROR, TRUE, GDBM_DEBUG_STORE);
@@ -39,8 +38,7 @@ write_header (GDBM_FILE dbf)
       return -1;
     }
 
-  rc = GDBM_DEBUG_OVERRIDE ("write_header:write-failure",
-	    _gdbm_full_write (dbf, dbf->header, dbf->header->block_size));
+  rc = _gdbm_full_write (dbf, dbf->header, dbf->header->block_size);
   
   if (rc)
     {
@@ -52,7 +50,7 @@ write_header (GDBM_FILE dbf)
 
   /* Sync the file if fast_write is FALSE. */
   if (dbf->fast_write == FALSE)
-    __fsync (dbf);
+    gdbm_file_sync (dbf);
 
   return 0;
 }
@@ -96,8 +94,7 @@ _gdbm_end_update (GDBM_FILE dbf)
   /* Write the directory. */
   if (dbf->directory_changed)
     {
-      file_pos = GDBM_DEBUG_OVERRIDE ("_gdbm_end_update:lseek-failure",
-		           __lseek (dbf, dbf->header->dir, SEEK_SET));
+      file_pos = gdbm_file_seek (dbf, dbf->header->dir, SEEK_SET);
       if (file_pos != dbf->header->dir)
 	{
 	  GDBM_SET_ERRNO2 (dbf, GDBM_FILE_SEEK_ERROR, TRUE, GDBM_DEBUG_STORE);
@@ -105,20 +102,19 @@ _gdbm_end_update (GDBM_FILE dbf)
 	  return -1;
 	}
 
-      rc = GDBM_DEBUG_OVERRIDE ("_gdbm_end_update:write-dir-failure",
-		_gdbm_full_write (dbf, dbf->dir, dbf->header->dir_size));
+      rc = _gdbm_full_write (dbf, dbf->dir, dbf->header->dir_size);
       if (rc)
 	{
 	  GDBM_DEBUG (GDBM_DEBUG_STORE|GDBM_DEBUG_ERR,
 		      "%s: error writing directory: %s",
 		      dbf->name, gdbm_db_strerror (dbf));	  	  
-	  _gdbm_fatal (dbf, gdbm_strerror (rc));
+	  _gdbm_fatal (dbf, gdbm_db_strerror (dbf));
 	  return -1;
 	}
 
       dbf->directory_changed = FALSE;
       if (!dbf->header_changed && dbf->fast_write == FALSE)
-	__fsync (dbf);
+	gdbm_file_sync (dbf);
     }
 
   /* Final write of the header. */
@@ -126,6 +122,8 @@ _gdbm_end_update (GDBM_FILE dbf)
     {
       if (write_header (dbf))
 	return -1;
+      if (_gdbm_file_extend (dbf, dbf->header->next_block))
+	return -1;
       dbf->header_changed = FALSE;
     }
 
